
/* Generated data (by glib-mkenums) */

#ifndef TERMINAL_TYPE_BUILTINS_H
#define TERMINAL_TYPE_BUILTINS_H

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "../../src/terminal-profile.h" */
GType terminal_title_mode_get_type (void);
#define TERMINAL_TYPE_TITLE_MODE (terminal_title_mode_get_type ())
GType terminal_scrollbar_position_get_type (void);
#define TERMINAL_TYPE_SCROLLBAR_POSITION (terminal_scrollbar_position_get_type ())
GType terminal_exit_action_get_type (void);
#define TERMINAL_TYPE_EXIT_ACTION (terminal_exit_action_get_type ())
GType terminal_background_type_get_type (void);
#define TERMINAL_TYPE_BACKGROUND_TYPE (terminal_background_type_get_type ())

G_END_DECLS

#endif /* !TERMINAL_TYPE_BUILTINS_H */

/* Generated data ends here */

